# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  # Bootloader.
  boot.loader.systemd-boot = {
    enable = true;
    memtest86.enable = true;
#    netbootxyz.enable = true;
  };
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.efi.efiSysMountPoint = "/boot/efi";

  boot.initrd.kernelModules = [ "amdgpu" ];
  boot.kernelParams = [
    "radeon.si_support=0"
    "radeon.cik_support=0"
    "amdgpu.cik_support=1"
    "amdgpu.si_support=1"
  ];

  # Setup keyfile
  boot.initrd.secrets = {
    "/crypto_keyfile.bin" = null;
  };

  # Enable swap on luks
  boot.initrd.luks.devices."luks-56936732-0a2c-4574-92c8-e9b114808694".device = "/dev/disk/by-uuid/56936732-0a2c-4574-92c8-e9b114808694";
  boot.initrd.luks.devices."luks-56936732-0a2c-4574-92c8-e9b114808694".keyFile = "/crypto_keyfile.bin";

  networking.hostName = "hennariikka"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.


	hardware.opengl.enable = true;
	hardware.opengl.driSupport = true;
	hardware.opengl.driSupport32Bit = true;
	hardware.opengl.extraPackages = with pkgs; [ mesa.drivers ];
	#hardware.opengl.extraPackages32 = with pkgs; [
	#  driversi686Linux.amdvlk
	#];


  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Enable networking
  networking.networkmanager.enable = true;

  # Set your time zone.
  time.timeZone = "Europe/Helsinki";

  # Select internationalisation properties.
  i18n.defaultLocale = "fi_FI.UTF-8";

  i18n.extraLocaleSettings = {
    LC_ADDRESS = "fi_FI.UTF-8";
    LC_IDENTIFICATION = "fi_FI.UTF-8";
    LC_MEASUREMENT = "fi_FI.UTF-8";
    LC_MONETARY = "fi_FI.UTF-8";
    LC_NAME = "fi_FI.UTF-8";
    LC_NUMERIC = "fi_FI.UTF-8";
    LC_PAPER = "fi_FI.UTF-8";
    LC_TELEPHONE = "fi_FI.UTF-8";
    LC_TIME = "fi_FI.UTF-8";
  };


 	  # Enable the X11 windowing system.
	  services.xserver = {
	    enable = true;
	    layout = "fi";
	    xkbVariant = "nodeadkeys";
	    libinput.enable = true;
	    displayManager = {
	      lightdm.enable = true;
	      autoLogin.enable = true;
	      autoLogin.user = "jt";
	    };
	    desktopManager = {
	      xterm.enable = false;
	      xfce = {
	        enable = true;
	        enableScreensaver = false;
	        thunarPlugins = [ pkgs.xfce.thunar-archive-plugin ];
	      };
	    };
	  };


  # Configure console keymap
  console.keyMap = "fi";

  # Enable CUPS to print documents.
  services.printing.enable = true;

  # Enable sound with pipewire.
  sound.enable = true;
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    # If you want to use JACK applications, uncomment this
    jack.enable = true;

    # use the example session manager (no others are packaged yet so this is enabled by default,
    # no need to redefine it in your config for now)
    #media-session.enable = true;
  };


	  # fonts.fontDir.enable = true;
	  # fonts.enableDefaultFonts = true;
	  fonts.fontconfig.defaultFonts.monospace = ["Fira Code"];
	  fonts.fonts = with pkgs; [
	    fira-code
	    fira-code-symbols
	    emacs-all-the-icons-fonts
        glasstty-ttf
	    #symbola
	    #fantasque-sans-mono
	    #noto-fonts
	    #noto-fonts-cjk
	    #noto-fonts-emoji
	  ];



	programs.steam = {
	  enable = true;
	  remotePlay.openFirewall = true; # Open ports in the firewall for Steam Remote Play
	  dedicatedServer.openFirewall = true; # Open ports in the firewall for Source Dedicated Server
	};

	  programs.dconf.enable = true;
	  programs.iftop.enable = true;
	  programs.iotop.enable = true;
	  programs.htop.enable = true;
	  programs.tmux.enable = true;


  # Enable touchpad support (enabled default in most desktopManager).
  # services.xserver.libinput.enable = true;

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.jt = {
    isNormalUser = true;
    description = "Jarkko Toivanen";
    extraGroups = [ "networkmanager" "wheel" ];
    packages = with pkgs; [
      firefox
      wineWowPackages.stable
	    winetricks
	    libreoffice
	    helvum
	    vlc
	    youtube-music
	    kate
	    kdenlive
	    gimp
	    discord
	    armcord
	    bitwarden
	    chiaki
	    prismlauncher
	    mangohud
	    #vulkan-tools
	    git
	    rustup
	    rust-analyzer
	    gcc
      obs-studio
      appimage-run
      steam-run-native

    #  thunderbird
    ];
  };

  # Allow unfree packages
  nixpkgs.config.allowUnfree = true;

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
    #  vim # Do not forget to add an editor to edit configuration.nix! The Nano editor is also installed by default.
    #  wget
 	    emacs
	    polkit_gnome
	    pavucontrol
	    pasystray
	    xarchiver
	    unrar
	    unzip
	    zip
	    p7zip
      graphite-gtk-theme
      tela-circle-icon-theme
  ];

	security.polkit.enable = true;


  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  # programs.gnupg.agent = {
  #   enable = true;
  #   enableSSHSupport = true;
  # };

  # List services that you want to enable:

  # Enable the OpenSSH daemon.
  services.openssh.enable = true;

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];
  # Or disable the firewall altogether.
  networking.firewall.enable = false;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.11"; # Did you read the comment?

}
