{ config, pkgs, ... }:
{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  # Use the GRUB 2 boot loader.
  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  # boot.loader.grub.efiSupport = true;
  # boot.loader.grub.efiInstallAsRemovable = true;
  # boot.loader.efi.efiSysMountPoint = "/boot/efi";
  # Define on which hard drive you want to install Grub.
  boot.loader.grub.device = "/dev/sda"; # or "nodev" for efi only

  networking.hostName = "leena"; # Define your hostname.
  networking.networkmanager.enable = true;  # Easiest to use and most distros use this by default.

  # Set your time zone.
  time.timeZone = "Europe/Helsinki";

  # Select internationalisation properties.
  i18n.defaultLocale = "fi_FI.UTF-8";
  console = {
    keyMap = "fi";
  #   useXkbConfig = true; # use xkbOptions in tty.
  };

  virtualisation = {
    podman = {
      enable = true;
      dockerCompat = true;
      defaultNetwork.dnsname.enable = true;
    };
  };

  nix.settings.auto-optimise-store = true;
  nixpkgs.config.allowUnfree = true;
  programs.iftop.enable = true;
  programs.iotop.enable = true;
  programs.htop.enable = true;
  programs.tmux.enable = true;
  programs.bash = {
    shellAliases = {
      cross="NIX_STORE=/nix/store cross";
    };
  };
  users.users.jt = {
    isNormalUser = true;
    extraGroups = [ "wheel" "networkmanager" ]; # Enable ‘sudo’ for the user.
    packages = with pkgs; [
      rustup
      rust-analyzer
      cargo-cross
      gcc
      #appimage-run
      steam-run-native
    ];
  };
  environment.systemPackages = with pkgs; [
    wget
    git
    emacs
    nano
    parted
    unrar
    unzip
    zip
    p7zip
    python3
  ];
  services.openssh.enable = true;
  services.cloudflare-dyndns = {
    enable = true;
    domains = [ "leena.jakest.us" ];
    apiTokenFile = "/home/jt/conf/cloudflare.token";
  };

  programs.gnupg.agent = {
    enable = true;
    pinentryFlavor = "gtk2";
    enableSSHSupport = true;
  };

  networking.firewall.enable = true;
  networking.firewall.allowedTCPPorts = [ 80 ];
  # networking.firewall.allowedUDPPorts = [ ... ];

  services.nginx = {
    enable = true;
    virtualHosts = {
      "leena.jakest.us" = {
        root = "/var/www/leena.jakest.us";
      };
    };
  };

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.11"; # Did you read the comment?

}

